==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/fa.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "مدیریت پارامترهای سبد آلبوم تصاویر");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "مدیریت گالری");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "اندازه کامل اندازه عرض عکس");
define('MANAGE_GALLERY_FULL_HEIGHT', "کامل اندازه ارتفاع تصویر");
define('MANAGE_GALLERY_THUMB_WIDTH', "عرض تصویر کوچک");
define('MANAGE_GALLERY_THUMB_HEIGHT', "تصویر بند انگشتی ارتفاع تصویر");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "حفظ نما نسبت تصویر");
define('MANAGE_GALLERY_SHOW_TITLES', "نشان دادن عناوین");
define('MANAGE_GALLERY_DISABLE_SORT', "غیر فعال کردن مرتب سازی بر");
define('MANAGE_GALLERY_DELETE_IMAGE', "حذف تصویر");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "ذخیره ترتیب");
define('MANAGE_GALLERY_PUBLISH_MSG', "کلیک کنید &#39;به روز رسانی &quot;را منتشر <br /> تصاویر آپلود شده خود را.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "تمام تصاویر تغییر سایز شده است و تنظیمات ذخیره شده اند.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "یک خطای تغییر اندازه تصاویر و یا صرفه جویی تنظیمات وجود دارد.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "تصویر خود را (بازدید کنندگان) آپلود شده است.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "خطایی هنگام آپلود تصویر خود را (بازدید کنندگان) وجود دارد.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "فایل شما در حال تلاش برای آپلود یک تصویر نیست.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "فایل شما در حال تلاش برای آپلود بیش از حد بزرگ است.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "عنوان ذخیره شده است.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "آیا مطمئن هستید که می خواهید به حذف تصویر");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "؟");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "تصویر حذف شده است.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "خطایی در حذف تصویر وجود دارد.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "صرفه جویی در پارامترهای و تغییر اندازه تصاویر، لطفا صبر کنید ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "آپلود، لطفا صبر کنید ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "ترتیب ذخیره نشد. آیا شما می خواهید برای ذخیره سفارش به مرتب کردن بر اساس؟");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "ترتیب تصویر ذخیره شده است.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "خطایی در ذخیره مرتب سازی بر تصویر وجود دارد.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/fa.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "مدیریت پارامترهای سبد آلبوم تصاویر");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "مدیریت گالری");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "اندازه کامل اندازه عرض عکس");
define('MANAGE_GALLERY_FULL_HEIGHT', "کامل اندازه ارتفاع تصویر");
define('MANAGE_GALLERY_THUMB_WIDTH', "عرض تصویر کوچک");
define('MANAGE_GALLERY_THUMB_HEIGHT', "تصویر بند انگشتی ارتفاع تصویر");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "حفظ نما نسبت تصویر");
define('MANAGE_GALLERY_SHOW_TITLES', "نشان دادن عناوین");
define('MANAGE_GALLERY_DISABLE_SORT', "غیر فعال کردن مرتب سازی بر");
define('MANAGE_GALLERY_DELETE_IMAGE', "حذف تصویر");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "ذخیره ترتیب");
define('MANAGE_GALLERY_PUBLISH_MSG', "کلیک کنید &#39;به روز رسانی &quot;را منتشر <br /> تصاویر آپلود شده خود را.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "تمام تصاویر تغییر سایز شده است و تنظیمات ذخیره شده اند.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "یک خطای تغییر اندازه تصاویر و یا صرفه جویی تنظیمات وجود دارد.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "تصویر خود را (بازدید کنندگان) آپلود شده است.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "خطایی هنگام آپلود تصویر خود را (بازدید کنندگان) وجود دارد.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "فایل شما در حال تلاش برای آپلود یک تصویر نیست.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "فایل شما در حال تلاش برای آپلود بیش از حد بزرگ است.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "عنوان ذخیره شده است.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "آیا مطمئن هستید که می خواهید به حذف تصویر");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "؟");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "تصویر حذف شده است.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "خطایی در حذف تصویر وجود دارد.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "صرفه جویی در پارامترهای و تغییر اندازه تصاویر، لطفا صبر کنید ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "آپلود، لطفا صبر کنید ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "ترتیب ذخیره نشد. آیا شما می خواهید برای ذخیره سفارش به مرتب کردن بر اساس؟");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "ترتیب تصویر ذخیره شده است.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "خطایی در ذخیره مرتب سازی بر تصویر وجود دارد.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "پرونده ای که می خواهید آپلود کنید بزرگتر از تنظیمات PHP &#39;upload_max_filesize&#39; یا &#39;post_max_size&#39; است. برای افزایش این محدودیت ها با سرپرست سیستم خود تماس بگیرید.");
?>
